Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1035)

Unified Diff: Source/core/workers/WorkerLoaderProxy.h

Issue 17648006: Rename WorkerContext to WorkerGlobalScope (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Rebase on master Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/workers/WorkerGlobalScopeProxy.cpp ('k') | Source/core/workers/WorkerMessagingProxy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/workers/WorkerLoaderProxy.h
diff --git a/Source/core/workers/WorkerLoaderProxy.h b/Source/core/workers/WorkerLoaderProxy.h
index ac5bc48aa2c69636babb79cde1fe9395f37bdf00..3342d900d77d41fea9a1288247dedb8d38ec683a 100644
--- a/Source/core/workers/WorkerLoaderProxy.h
+++ b/Source/core/workers/WorkerLoaderProxy.h
@@ -53,10 +53,10 @@ namespace WebCore {
// Posts a task to the thread which runs the loading code (normally, the main thread).
virtual void postTaskToLoader(PassOwnPtr<ScriptExecutionContext::Task>) = 0;
// Posts callbacks from loading code to the WorkerContext. The 'mode' is used to differentiate
// specific synchronous loading requests so they can be 'nested', per spec.
// Returns true if the task was posted successfully.
- virtual bool postTaskForModeToWorkerContext(PassOwnPtr<ScriptExecutionContext::Task>, const String& mode) = 0;
+ virtual bool postTaskForModeToWorkerGlobalScope(PassOwnPtr<ScriptExecutionContext::Task>, const String& mode) = 0;
// Spans divergent class hierarchies for dedicated and shared workers.
virtual WebKit::WebWorkerBase* toWebWorkerBase() = 0;
« no previous file with comments | « Source/core/workers/WorkerGlobalScopeProxy.cpp ('k') | Source/core/workers/WorkerMessagingProxy.h » ('j') | no next file with comments »
@@ -53,10 +53,10 @@ namespace WebCore {
// Posts a task to the thread which runs the loading code (normally, the main thread).
virtual void postTaskToLoader(PassOwnPtr<ScriptExecutionContext::Task>) = 0;
- // Posts callbacks from loading code to the WorkerContext. The 'mode' is used to differentiate
+ // Posts callbacks from loading code to the WorkerGlobalScope. The 'mode' is used to differentiate
// specific synchronous loading requests so they can be 'nested', per spec.
// Returns true if the task was posted successfully.

Powered by Google App Engine
This is Rietveld 408576698